"""A collection of definitions for generated benchmark scenarios.

Each generated scenario is defined by the a number of parameters that
control the size of the problem (see scenario.generator for more info):

There are also some parameters, where default values are used for all
scenarios, see DEFAULTS dict.
"""

# generated environment constants
DEFAULTS = dict(
    num_exploits=None,
    num_privescs=None,
    r_sensitive=100,
    r_user=100,
    exploit_cost=1,
    exploit_probs='mixed',
    privesc_cost=1,
    privesc_probs=1.0,
    service_scan_cost=1,
    os_scan_cost=1,
    subnet_scan_cost=1,
    process_scan_cost=1,
    uniform=False,
    alpha_H=2.0,
    alpha_V=2.0,
    lambda_V=1.0,
    random_goal=False,
    base_host_value=1,
    host_discovery_value=1,
    step_limit=1000
)

# Generated Scenario definitions
TESTAG_GEN = {**DEFAULTS,
            "name": "testag-gen",
            "num_hosts": 3,
            "num_os": 1,
            "num_services": 1,
            "num_processes": 1,
            "restrictiveness": 1}

AVAIL_GEN_BENCHMARKS = {
    "testag-gen": TESTAG_GEN,
}



import os.path as osp

from .generated import AVAIL_GEN_BENCHMARKS

BENCHMARK_DIR = osp.dirname(osp.abspath(__file__))

AVAIL_STATIC_BENCHMARKS = {
    "testag": {
        "file": osp.join(BENCHMARK_DIR, "testag.yaml"),
        "name": "testag",
        "step_limit": 1000,
        "max_score": 195
    },
    
    "enterprise": {
        "file": osp.join(BENCHMARK_DIR, "enterprise.yaml"),
        "name": "enterprise",
        "step_limit": 2000,
        "max_score": 190
    },
    "onesite_enterprise": {
        "file": osp.join(BENCHMARK_DIR, "onesite_enterprise.yaml"),
        "name": "onesite_enterprise",
        "step_limit": 2000,
        "max_score": 195
    },
    "multisite_enterprise": {
        "file": osp.join(BENCHMARK_DIR, "multisite_enterprise.yaml"),
        "name": "multisite_enterprise",
        "step_limit": 2000,
        "max_score": 190
    },
}

AVAIL_BENCHMARKS = list(AVAIL_STATIC_BENCHMARKS.keys()) \
                    + list(AVAIL_GEN_BENCHMARKS.keys())



from setuptools import setup, find_packages

extras = {
    'dqn': [
        'torch>=1.5',
        'tensorboard>=2.2'
    ],
    'docs': [
        'sphinx>=3.0',
        'sphinx-rtd-theme>=0.4'
    ],
    'test': [
        'pytest>=5.4'
    ]
}

extras['all'] = [item for group in extras.values() for item in group]

setup(
    name='cyberrl',
    version='0.100.0',
    description="CyberRL",
    author="DE",
    author_email="cyberrldevelopment@gmail.com",
    packages=[
        package for package in find_packages()
        if package.startswith('cyberrl')
    ],
    install_requires=[
        'gym>=0.17',
        'numpy>=1.18',
        'networkx>=2.4',
        'matplotlib>=3.1',
        'pyyaml>=5.3',
        'prettytable>=0.7'
    ],
    extras_require=extras,
    python_requires='>=3.7',
    package_data={
        'cyberrl': ['scenarios/benchmark/*.yaml']
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    zip_safe=False
)
